package com.example.dbtest;

import java.io.BufferedReader;
import java.io.File;
import java.io.InputStreamReader;

import android.os.Bundle;
import android.os.Environment;
import android.app.Activity;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;


public class MainActivity extends Activity {

   	private SQLiteDatabase db = null;
   	private String DATABASE_NAME = Environment.getExternalStorageDirectory().getName() +
   								   "/tutor/cities.db" ;	

	private Cursor gc = null;
   	private TextView code;
   	private EditText cityName;

   	private boolean editViewActive = true;
   	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		//setContentView(R.layout.activity_main);
		setContentView(R.layout.db_handle);

		code = (TextView)findViewById(R.id.textView2);
		cityName = (EditText)findViewById(R.id.editText1);
		
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}
	
    public boolean onOptionsItemSelected(MenuItem item) {
        
        switch (item.getItemId()) {
        case R.id.db_open: 
        	 try{
        		 
        		 File f = new File(DATABASE_NAME);
        		 
                 db = openOrCreateDatabase(f.getAbsolutePath(), MODE_PRIVATE, null);
                 Toast.makeText(getApplicationContext(),
                         DATABASE_NAME + "\nDB Connected", 
                         Toast.LENGTH_LONG).show();
        	 }
        	 catch (Exception e){
                 Toast.makeText(getApplicationContext(),
                         DATABASE_NAME + "\n" +e.getMessage(), 
                         Toast.LENGTH_LONG).show();
        		 
        	 }
             break;
             
        case R.id.create_table:  
       	 doTable();
       	 break;

        case R.id.copy_data:  
       	 	fillData();
       	 break;

        case R.id.get_records:
        	getRecords();
        	break;

        case R.id.open_table :
       	 tableOpen();    	 
       	 break;

        case R.id.view_sw:
        	if(editViewActive){
        		gc.close(); gc=null;
        		setContentView(R.layout.activity_main);
        		getRecords();
        	}
        	else {
        		setContentView(R.layout.db_handle);
        		code = (TextView)findViewById(R.id.textView2);
        		cityName = (EditText)findViewById(R.id.editText1);
        		tableOpen();
        	}
        	editViewActive = !editViewActive;
        	break;

        default:
        return super.onOptionsItemSelected(item);
        }
        
        return true;
    }
   
    public void tableOpen(){

    	
	    if (db==null)
            Toast.makeText(getApplicationContext(),
                    "Open Database first", 
                    Toast.LENGTH_LONG).show();
	    else{
	    	
	    	gc = db.query("cities", null, null, null, null, null, null);
	    	gc.moveToFirst();
	    	code.setText(gc.getString(gc.getColumnIndex("id")) );
	    	cityName.setText(gc.getString(gc.getColumnIndex("name")) );
	    	
	    }

    }
    
	public void doTable(){
		
	    String CITIES_CREATE =
	            "create table cities(id integer primary key autoincrement, "
	                + "name text not null"
	                +");";
	    
	    if (db==null)
            Toast.makeText(getApplicationContext(),
                    "Open Database first", 
                    Toast.LENGTH_LONG).show();
	    else{
	    	
	    	try{
	    		db.execSQL(CITIES_CREATE);
	    		Toast.makeText(getApplicationContext(),
                    "Table Created!", 
                    Toast.LENGTH_LONG).show();
	    	}
	    	catch (Exception e){
	    		Toast.makeText(getApplicationContext(),
                    "Error Creating table!" + "\n" +e.getMessage(), 
                    Toast.LENGTH_LONG).show();	
	    	}
	    }
	}

	public void fillData(){
		
	    String Query = "";

	    if (db==null)
            Toast.makeText(getApplicationContext(),
                    "Open Database first", 
                    Toast.LENGTH_LONG).show();
	    else{
	    	
	    	try{

	    		    BufferedReader reader = new BufferedReader(
	    		        new InputStreamReader(getAssets().open("cities.txt"), "UTF-8")); 

	    		    String mLine = reader.readLine();
	    		    while (mLine != null) {
	    		    	Query = "insert into cities (name) values (\"" +
	    		    			mLine +  "\")";
	    		    	db.execSQL(Query);
	    		    	mLine = reader.readLine(); 
	    		    }
	    		    reader.close();
		    		Toast.makeText(getApplicationContext(),
		                    "Data inserted to table cities!", 
		                    Toast.LENGTH_LONG).show();	
	    	
	    	}
	    	catch (Exception e){
	    		Toast.makeText(getApplicationContext(),
                    "Error Filling Data!" + "\n" +e.getMessage(), 
                    Toast.LENGTH_LONG).show();	
	    	}
	    }
	}

	public void getRecords(){
		
		ListView listView1 = (ListView) findViewById(R.id.listView1);
		
		try{
			
			Cursor c = db.query("cities", null, null, null, null, null, null);
			int recCount = c.getCount();
			String[] cities = new String[recCount]; // recCount cities !?

			int i = 0;
			
			c.moveToFirst();
			for(i = 0; i < recCount; i++){
				cities[i] = c.getString(c.getColumnIndex("name"));
				c.moveToNext();
			}
			
			c.close();
	        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this,
	                android.R.layout.simple_list_item_1, cities);
	    
	        listView1.setAdapter(adapter);

			
		}
		catch (Exception e){
    		Toast.makeText(getApplicationContext(),
                    "Error Filling ListView!" + "\n" +e.getMessage(), 
                    Toast.LENGTH_LONG).show();	
			
		}
		
	}

	public void handleAction( View v){
		
		String Query="";
		
		switch (v.getId())
		{
		case R.id.imageButton1: gc.moveToFirst(); break;
		case R.id.imageButton2: if (!gc.isFirst()) gc.moveToPrevious(); break;
		case R.id.imageButton3: if (!gc.isLast()) gc.moveToNext(); break;
		case R.id.imageButton4: gc.moveToLast(); break;
		case R.id.imageButton5: int p = gc.getPosition();
								gc.close(); gc=null;
								Query = "update cities set name=\"" +
										cityName.getText().toString() +
										"\" where id=" +
										code.getText();
								db.execSQL(Query);
								tableOpen();
								gc.moveToPosition(p);
								break;
		case R.id.imageButton6: gc.close(); gc=null;
								Query = "insert into cities (name) values (\"" +
										cityName.getText().toString() + "\")";
								db.execSQL(Query);
								tableOpen();
								gc.moveToLast();
								break;
		case R.id.imageButton7: p = gc.getPosition();
								gc.close(); gc = null;
								Query = "delete from cities where id="+
										code.getText();
								db.execSQL(Query);
								tableOpen();
								p--;
								if (p < 0) p=0;
								gc.moveToPosition(p);
								break;
		case R.id.imageButton8: gc.close();	gc = null;
								tableOpen();
								break;
		}
		
    	code.setText(gc.getString(gc.getColumnIndex("id")) );
    	cityName.setText(gc.getString(gc.getColumnIndex("name")) );

	}

}


/*
 
         	
        	

 
 */

